def get_allowed_system_dependencies():
    allowed_system_dependencies = [
        "libffi-dev",
        "default-jre",
        "openjdk-11-jre-headless",
        "openjdk-8-jre-headless"
    ]
    return allowed_system_dependencies
